""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.unvs.schemas import models

""" UNVS API Schema
"""


"""
API: GetMobile

一键登录
"""


class GetMobileRequestSchema(schema.RequestSchema):
    """GetMobile - 一键登录"""

    fields = {
        "BusinessId": fields.Str(required=True, dump_to="BusinessId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "Token": fields.Str(required=True, dump_to="Token"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetMobileResponseSchema(schema.ResponseSchema):
    """GetMobile - 一键登录"""

    fields = {
        "Data": models.PhoneInfoSchema(),
        "Message": fields.Str(required=False, load_from="Message"),
        "ReqUuid": fields.Str(required=False, load_from="ReqUuid"),
    }


"""
API: VerifyMobile

号码检测
"""


class VerifyMobileRequestSchema(schema.RequestSchema):
    """VerifyMobile - 号码检测"""

    fields = {
        "BusinessId": fields.Str(required=True, dump_to="BusinessId"),
        "Phone": fields.Str(required=True, dump_to="Phone"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "Token": fields.Str(required=True, dump_to="Token"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class VerifyMobileResponseSchema(schema.ResponseSchema):
    """VerifyMobile - 号码检测"""

    fields = {
        "Data": models.VerifyInfoSchema(),
        "Message": fields.Str(required=False, load_from="Message"),
        "ReqUuid": fields.Str(required=False, load_from="ReqUuid"),
    }
