""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.iam.schemas import models

""" IAM API Schema
"""


"""
API: CreateProject

创建项目
"""


class CreateProjectRequestSchema(schema.RequestSchema):
    """CreateProject - 创建项目"""

    fields = {
        "ProjectName": fields.Str(required=True, dump_to="ProjectName"),
    }


class CreateProjectResponseSchema(schema.ResponseSchema):
    """CreateProject - 创建项目"""

    fields = {
        "ProjectId": fields.Str(required=True, load_from="ProjectId"),
    }


"""
API: DeleteProject

删除项目
"""


class DeleteProjectRequestSchema(schema.RequestSchema):
    """DeleteProject - 删除项目"""

    fields = {
        "ProjectID": fields.Str(required=True, dump_to="ProjectID"),
    }


class DeleteProjectResponseSchema(schema.ResponseSchema):
    """DeleteProject - 删除项目"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }
