""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class PhoneInfoSchema(schema.ResponseSchema):
    """PhoneInfo - 号码信息"""

    fields = {
        "Phone": fields.Str(required=False, load_from="Phone"),
    }


class VerifyInfoSchema(schema.ResponseSchema):
    """VerifyInfo - 检测结果信息"""

    fields = {
        "VerifyResult": fields.Str(required=False, load_from="VerifyResult"),
    }
