""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uvms.schemas import models

""" UVMS API Schema
"""


"""
API: SendUVMSMessage

向指定号码拨打电话
"""


class SendUVMSMessageRequestSchema(schema.RequestSchema):
    """SendUVMSMessage - 向指定号码拨打电话"""

    fields = {
        "CalledNumber": fields.Str(required=True, dump_to="CalledNumber"),
        "DispatchRule": fields.Int(required=False, dump_to="DispatchRule"),
        "FromNumber": fields.Str(required=False, dump_to="FromNumber"),
        "GroupType": fields.Int(required=False, dump_to="GroupType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(
            required=True, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
        "TemplateParams": fields.List(fields.Str()),
        "UserId": fields.Str(required=False, dump_to="UserId"),
        "Zone": fields.Str(
            required=True, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class SendUVMSMessageResponseSchema(schema.ResponseSchema):
    """SendUVMSMessage - 向指定号码拨打电话"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=True, load_from="ReqUuid"),
        "SessionNo": fields.Str(required=False, load_from="SessionNo"),
        "UserId": fields.Str(required=False, load_from="UserId"),
    }
